docs.rs failed to build ling-py-2030.0.1
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
ling-py-2030.0.0
ling-py — PyO3 bindings for ling-audio, ling-physics, and WebSocket netplay.
Python classes exposed: AudioEngine — 4D spatial audio synthesis (wraps ling_audio::AudioEngine) HyperbolicWorld — Poincaré-ball hyperbolic sphere world (wraps ling_physics::hyperbolic) NetClient — async WebSocket client for netplay